Class: ZabbixManager::Events

Inherits:
Basic
  • Object
show all
Defined in:
lib/zabbix_manager/classes/events.rb

Instance Method Summary collapse

Methods inherited from Basic

#add, #all, #create, #create_or_update, #create_raw, #default_options, #delete, #delete_raw, #destroy, #dump_by_id, #get, #get_full_data, #get_hostgroup_ids, #get_id, #get_or_create, #get_or_create_hostgroups, #get_raw, #hash_equals?, #initialize, #key, #keys, #log, #merge_params, #mojo_update, #normalize_array, #normalize_hash, #parse_keys, #symbolize_keys, #update, #update_raw

Constructor Details

This class inherits a constructor from ZabbixManager::Basic

Instance Method Details

#identifyString

The id field name used for identifying specific Event objects via Zabbix API

Returns:

  • (String)


15
16
17
# File 'lib/zabbix_manager/classes/events.rb', line 15

def identify
  "name"
end

#method_nameString

The method name used for interacting with Events via Zabbix API

Returns:

  • (String)


8
9
10
# File 'lib/zabbix_manager/classes/events.rb', line 8

def method_name
  "event"
end